import Taro, { Component } from '@tarojs/taro'
import { View, Button, Text, Image, Input } from '@tarojs/components'
import { AtIcon, AtModal, AtModalHeader, AtModalContent, AtModalAction, AtNoticebar } from 'taro-ui'

import VoucherPosterComponent from './voucherPosterComponent/voucherPosterComponent'

import './filteredShopComponent.scss'
import URL from '../../serviceAPI.config'

const hornIcon = require('../../icons/horn.png')
const houseIcon = require('../../icons/house.png')

class recommondShop extends Component {

    static defaultProps = {
        shop: {
            shop_name: 'kobe',
            goods: [{ goods_url: 'www.kobe.com', goods_price: '999', goods_name: 'kobe' }],
            shop_address: 'kobe road',
            distance: '247km',
            ads: 'Have you ever seen Los Angels sun dawn in 4 AM in the morning?',
            left_nums: '999'
        }
    }

    config = {
        navigationBarTitleText: 'recommondShop'
    }
    constructor() {
        super(...arguments);
        this.state = {
            isOpenVoucher: false,
            isOpenConsult: false,
            consultTip: '',
            voucherResponseMsg: '',
            voucherCanConsult: false,
            userName: Taro.getStorageSync('user_identity').username,
            userPhone: Taro.getStorageSync('user_identity').userphone,
        }
    }
    goToShop(value) {
        Taro.navigateTo({
            url: '/pages/shop/shop?id=' + value.shop_id
        })
    }
    // api 优惠卷请求  
    getVoucherInfo({ user = "杨夕兵", phone = "18950295811", shops = ["808"], source_type = 4, flag = false, source_class = "1", source_level = 1 }) {
        Taro.request({
            url: URL.GetVoucherInfo,
            method: 'POST',
            dataType: 'json',
            data: {
                user: user,
                phone: phone,
                shops: shops,
                source_type: source_type,
                flag: flag,
                source_class: source_class,
                source_level: source_level
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                this.setState({
                    voucherResponseMsg: res.data.tips,
                    voucherCanConsult: res.data.canConsult
                })
                console.log('优惠卷请求', res)
            })

    }
    // api 咨询信息 

    getConsultInfo({ user = "杨夕兵", phone = "18950295811", shops = ["1306"], source_type = "2", flag = false, source_level = 1 }) {
        Taro.request({
            url: URL.GetConsultInfo,
            method: 'POST',
            dataType: 'json',
            data: {
                user: user,
                phone: phone,
                shops: shops,
                source_type: source_type,
                flag: flag,
                source_level: source_level
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                this.setState({ consultTip: res.data.tips })
                console.log('咨询请求', res)
            })
    }
    // api 购买咨询 BuyConsult
    buyConsult({ user = "杨夕兵", phone = "18950295811", shops = ["1306"], source_type = "2", source_level = 1, coupons_flag = 0 }) {
        Taro.request({
            url: URL.BuyConsult,
            method: 'POST',
            dataType: 'json',
            data: {
                data: JSON.stringify({
                    user: user,
                    phone: phone,
                    shops: shops,
                    source_type: source_type,
                    source_level: source_level,
                    coupons_flag: coupons_flag,
                })
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                console.log('购买咨询请求成功', res)
                if (res.statusCode === 200) {
                    Taro.showToast({ title: '咨询成功', icon: 'success' })
                } else {
                    Taro.showToast({ title: res.data.err_msg, icon: 'none' })

                }
            }).catch(err => {
                console.log('购买咨询请求失败', err)
            })
    }

    // 优惠卷弹框。取消。确认
    isOpenVoucher() {
        this.setState({ isOpenVoucher: true })
        this.getVoucherInfo({})
    }
    voucherModalClose() {
        this.setState({ isOpenVoucher: false })
    }
    voucherModalConfirm() {
        this.setState({ isOpenVoucher: false })
        this.buyConsult({ user: this.state.userName, phone: this.state.userPhone })
    }
    // 咨询弹框。取消。确认
    isOpenConsult() {
        this.setState({ isOpenConsult: true })
        this.getConsultInfo({})
    }
    consultModalClose() {
        this.setState({ isOpenConsult: false })
    }
    consultModalConfirm() {
        this.setState({ isOpenConsult: false })
        this.buyConsult({ user: this.state.userName, phone: this.state.userPhone })
    }
    handleInputVcherPhone(value) {
        this.setState({ userPhone: value })
    }
    handleInputVcherName(value) {
        this.setState({ userName: value })
    }
    handleInputCsultName(value) {
        this.setState({ userName: value })
    }
    handleInputCsultPhone(value) {
        this.setState({ userPhone: value })
    }
    getDataFromChild(value) {
        console.log('从voucherposter件传回来的值', value)
        this.setState({ isOpenVoucher: value })
    }


    componentWillReceiveProps(nextProps) {
        //console.log(this.props, nextProps)
    }
    componentDidMount() {

    }
    componentWillUnmount() { }

    componentDidShow() { }

    componentDidHide() { }


    render() {
        const title = this.props.shop.shop_name
        const imgUrl = URL.Base + this.props.shop.goods[0].goods_url
        const price = this.props.shop.goods[0].goods_price
        const goods = this.props.shop.goods
        const ProductName = this.props.shop.goods[0].goods_name
        const address = this.props.shop.shop_address
        const distance = this.props.shop.distance
        const ads = this.props.shop.ads
        const voucherLeft = this.props.shop.left_nums // 优惠卷是否为灰色
        const isShowConsultButton = this.props.shop.wx_open === '0' ? false : true // 优惠卷是否为灰色
        const slicedGoods = goods !== null ? goods.slice(1) : null
        const goodsElementsArray = goods !== null ? slicedGoods.map((item, index) => {
            return <View className='goods-img-box' key={index}>
                <Image className='goods-img' onClick={this.goToShop.bind(this, this.props.shop)}
                    mode='aspectFit' style='max-height: 100%; max-width: 100%;'
                    src={URL.Base + item.goods_url}
                />
            </View>
        }) : null

        //  优惠卷和咨询元素
        const consultModalElement = <AtModal isOpened={this.state.isOpenConsult}>
            <AtModalHeader>咨询</AtModalHeader>
            <AtModalContent>

                <AtNoticebar >
                    <Text >提示:{this.state.consultTip}</Text>
                </AtNoticebar>
                <View className='input-box' style='display:flex; align-items:center; font-size:28rpx; margin:2% 2%'>
                    <View className='title'>
                        <Text>联系人：</Text>
                    </View>
                    <Input name='value'
                        type='text'
                        value={this.state.userName}
                        onInput={this.handleInputCsultName.bind(this)}
                    />

                </View>
                <View className='input-box' style='display:flex; align-items:center; font-size:28rpx; margin-left:2%'>
                    <View className='title'>
                        <Text>联系电话：</Text>
                    </View>
                    <Input name='value'
                        type='number'
                        maxLength='11'
                        value={this.state.userPhone}
                        onInput={this.handleInputCsultPhone.bind(this)}
                    />
                </View>
            </AtModalContent>
            <AtModalAction> <Button onClick={this.consultModalClose.bind(this)} >取消</Button> <Button style='color:#FF7142' onClick={this.consultModalConfirm.bind(this)}>确定</Button> </AtModalAction>
        </AtModal>


        return (
            <View className='shop-list-box' >
                {voucherModalElement}
                {consultModalElement}
                <VoucherPosterComponent isVoucherPoster={this.state.isOpenVoucher}
                    onPassDataToChild={this.getDataFromChild.bind(this)}
                    voucherLeft={this.props.shop.left_nums}
                    voucherResponseMsg={this.state.voucherResponseMsg}
                ></VoucherPosterComponent>
                <View className='header'>

                    <View className='title'>
                        <Image src={ads !== 0 ? hornIcon : houseIcon} style='width:12px; height:12px; vertical-align: middle;' />
                        <Text style='margin-left:2px; vertical-align: middle;'>  {title}</Text>
                    </View>

                    <View className='button-container' style='margin-right:5px'>
                        {voucherLeft ? <View className='button' onClick={this.isOpenVoucher.bind(this)} >
                            <Button size='mini' className='button-blue-mini'>
                                优惠卷</Button>
                        </View> : <View className='button blur' onClick={this.isOpenVoucher.bind(this)} >
                                <Button size='mini' className='button-blue-mini'>优惠卷</Button>
                            </View>}

                        {isShowConsultButton ? <View className='button contult-button' onClick={this.isOpenConsult.bind(this)} >
                            <Button size='mini' className='button-blue-mini'>
                                询价</Button>
                        </View> : null}

                    </View>
                </View>
                <View className='body'>
                    <View className='shop-img' onClick={this.goToShop.bind(this, this.props.shop)}>
                        <Image mode='aspectFit' style=' max-height: 100%; max-width: 100%;' src={imgUrl} />
                    </View>
                    {goods.length !== 1 ? <View className='images'>{goodsElementsArray}</View> : <View className='details'>
                        <View className='details-block'><Text className='details-text'>商品:</Text> {ProductName}</View>
                        <View className='details-block'><Text className='details-text'>价格: </Text><Text>{price}</Text></View>
                    </View>}

                </View>
                <View className='footer'>
                    <View className='address'>
                        <AtIcon value='map-pin' size='15' color='#999'></AtIcon>
                        <Text>{address} </Text> </View>
                    <View className='distance'><Text>{distance}</Text></View>

                </View>
            </View>
        )
    }
}

export default recommondShop
